# QuickDataFlow

[![Build Status](https://travis-ci.com/ilyajob05/QuickDataFlow.svg?branch=main)](https://travis-ci.com/ilyajob05/QuickDataFlow)
[![codecov](https://codecov.io/gh/ilyajob05/QuickDataFlow/branch/main/graph/badge.svg?token=T2M14V6SK8)](https://codecov.io/gh/ilyajob05/QuickDataFlow)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=ilyajob05_QickDataFlow&metric=alert_status)](https://sonarcloud.io/dashboard?id=ilyajob05_QickDataFlow)
[![CMake](https://github.com/ilyajob05/QuickDataFlow/actions/workflows/cmake.yml/badge.svg)](https://github.com/ilyajob05/QuickDataFlow/actions/workflows/cmake.yml)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://raw.githubusercontent.com/ilyajob05/QuickDataFlow/main/LICENSE)
![PyPI](https://img.shields.io/pypi/v/QuickDataFlow?label=pypi%20QuickDataFlow)
<!--- ![PyPI - Downloads](https://img.shields.io/pypi/dm/QuickDataFlow)
--->

This library is for building multithreaded and fast C++ applications

## Requirements
gtest

## Usage
### Build for C++
```
git clone https://github.com/ilyajob05/QuickDataFlow.git
cd QuickDataFlow
chmod +x build.sh
./build.sh
```
### Install from deb
Your need build library before install
```
sudo pdkg -i build/QuickDataFlow-2.1.0-Linux.deb
```

### Install from Pypi
```
pip install QuickDataFlow
```

![](./output.png)
